@@ -353,7 +353,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 		
 		gnome_vfs_uri_unref (uri);
 		g_assert (progress_verb);
-		progress_label_text = g_strdup_printf ("%s:", progress_verb);
+		progress_label_text = g_strdup_printf ("%s", progress_verb);
 		/* "From" dialog label, source path gets placed next to it in the dialog */
 		from_prefix = _("From:");
 	}
@@ -932,36 +932,25 @@ handle_transfer_vfs_error (const GnomeVFSXferProgressInfo *progress_info,
 				TRUE, GTK_MESSAGE_ERROR, text, detail, dialog_title, GTK_STOCK_OK, NULL);
 			error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
 
-		} else if ((error_location == ERROR_LOCATION_SOURCE
-				|| error_location == ERROR_LOCATION_SOURCE_PARENT
-				|| error_location == ERROR_LOCATION_SOURCE_OR_PARENT)
-			&& (error_kind == ERROR_NOT_ENOUGH_PERMISSIONS
-				|| error_kind == ERROR_NOT_READABLE)) {
-			/* The error could have happened on any of the files
-			 * in the moved/copied/deleted hierarchy, we can probably
-			 * continue. Allow the user to skip.
-			 */
+		} else if (progress_info->files_total == 1) {
 			error_dialog_button_pressed = eel_run_simple_dialog
 				(parent_for_error_dialog (transfer_info), TRUE, 
 				 GTK_MESSAGE_ERROR, text, 
 				 detail, dialog_title,
-				 GTK_STOCK_CANCEL, _("_Skip"), NULL);
-				 
+				 GTK_STOCK_CANCEL, _("_Retry"), NULL);
+
 			switch (error_dialog_button_pressed) {
 			case 0:
-			case GTK_RESPONSE_DELETE_EVENT:
 				error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
 				break;
 			case 1:
-				error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_SKIP;
+				error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_RETRY;
 				break;
 			default:
 				g_assert_not_reached ();
 				error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
 			}
-								
 		} else {
-			/* Generic error, offer to retry and skip. */
 			error_dialog_button_pressed = eel_run_simple_dialog
 				(parent_for_error_dialog (transfer_info), TRUE, 
 				 GTK_MESSAGE_ERROR, text, 
@@ -983,7 +972,7 @@ handle_transfer_vfs_error (const GnomeVFSXferProgressInfo *progress_info,
 				error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
 			}
 		}
-			
+
 		g_free (text);
 		g_free (detail);
 		g_free (formatted_source_name);
@@ -2461,11 +2450,12 @@ nautilus_file_operations_delete (const GList *item_uris,
 
 					link = nautilus_desktop_icon_file_get_link (NAUTILUS_DESKTOP_ICON_FILE (file));
 
-					nautilus_desktop_link_monitor_delete_link (nautilus_desktop_link_monitor_get (),
-										   link,
-										   parent_view);
-					
-					g_object_unref (link);
+					if (link != NULL) {
+						nautilus_desktop_link_monitor_delete_link (nautilus_desktop_link_monitor_get (),
+											   link,
+											   parent_view);
+						g_object_unref (link);
+					}
 				}
 				nautilus_file_unref (file);
 			}
