@@ -364,6 +364,8 @@ void                fm_directory_view_pop_up_background_context_menu   (FMDirect
 									GdkEventButton   *event);
 void                fm_directory_view_pop_up_selection_context_menu    (FMDirectoryView  *view,
 									GdkEventButton   *event); 
+void                fm_directory_view_pop_up_location_context_menu     (FMDirectoryView  *view,
+									GdkEventButton   *event); 
 void                fm_directory_view_send_selection_change            (FMDirectoryView *view);
 gboolean            fm_directory_view_should_show_file                 (FMDirectoryView  *view,
 									NautilusFile     *file);
@@ -384,4 +386,7 @@ void                fm_directory_view_handle_uri_list_drop             (FMDirect
 									GdkDragAction     action,
 									int               x,
 									int               y);
+void                fm_directory_view_freeze_updates                   (FMDirectoryView  *view);
+void                fm_directory_view_unfreeze_updates                 (FMDirectoryView  *view);
+
 #endif /* FM_DIRECTORY_VIEW_H */
