@@ -827,6 +827,13 @@ sort_column_changed_callback (GtkTreeSortable *sortable,
 				    default_reversed_attr, reversed_attr);
 }
 
+static void
+cell_renderer_editing_canceled (GtkCellRendererText *cell,
+				FMListView          *view)
+{
+	fm_directory_view_unfreeze_updates (FM_DIRECTORY_VIEW (view));
+}
+
 static void
 cell_renderer_edited (GtkCellRendererText *cell,
 		      const char          *path_str,
@@ -873,6 +880,7 @@ cell_renderer_edited (GtkCellRendererText *cell,
 		      "editable", FALSE,
 		      NULL);
 
+	fm_directory_view_unfreeze_updates (FM_DIRECTORY_VIEW (view));
 }
 
 static char *
@@ -1125,6 +1133,7 @@ create_and_set_up_tree_view (FMListView *view)
 			cell = gtk_cell_renderer_text_new ();
 			view->details->file_name_cell = (GtkCellRendererText *)cell;
 			g_signal_connect (cell, "edited", G_CALLBACK (cell_renderer_edited), view);
+			g_signal_connect (cell, "editing-canceled", G_CALLBACK (cell_renderer_editing_canceled), view);
 			
 			gtk_tree_view_column_pack_start (view->details->file_name_column, cell, TRUE);
 			gtk_tree_view_column_set_attributes (view->details->file_name_column, cell,
@@ -1931,6 +1940,9 @@ fm_list_view_start_renaming_file (FMDirectoryView *view, NautilusFile *file)
 		return;
 	}
 
+	/* Freeze updates to the view to prevent losing rename focus when the tree view updates */
+	fm_directory_view_freeze_updates (FM_DIRECTORY_VIEW (view));
+
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (list_view->details->model), &iter);
 
 	/*Make filename-cells editable.*/
@@ -2339,7 +2351,11 @@ fm_list_view_supports_uri (const char *uri,
 static NautilusViewInfo fm_list_view = {
 	FM_LIST_VIEW_ID,
 	N_("List"),
-	N_("_List"),
+	N_("View as List"),
+	N_("View as _List"),
+	N_("The list view encountered an error."),
+	N_("The list view encountered an error while starting up."),
+	N_("Display this location with the list view."),
 	fm_list_view_create,
 	fm_list_view_supports_uri
 };
@@ -2348,7 +2364,11 @@ void
 fm_list_view_register (void)
 {
 	fm_list_view.label = _(fm_list_view.label);
-	fm_list_view.label_with_mnemonic = _(fm_list_view.label_with_mnemonic);
-	
+	fm_list_view.view_as_label = _(fm_list_view.view_as_label);
+	fm_list_view.view_as_label_with_mnemonic = _(fm_list_view.view_as_label_with_mnemonic);
+	fm_list_view.error_label = _(fm_list_view.error_label);
+	fm_list_view.startup_error_label = _(fm_list_view.startup_error_label);
+	fm_list_view.display_location_label = _(fm_list_view.display_location_label);
+
 	nautilus_view_factory_register (&fm_list_view);
 }
