@@ -83,8 +83,10 @@
 #include <libnautilus-private/nautilus-desktop-link-monitor.h>
 #include <libnautilus-private/nautilus-directory-private.h>
 #include <bonobo-activation/bonobo-activation.h>
+#ifdef HAVE_STARTUP_NOTIFICATION
 #define SN_API_NOT_YET_FROZEN Yes_i_know_DO_IT
 #include <libsn/sn-launchee.h>
+#endif
 
 /* Needed for the is_kdesktop_present check */
 #include <gdk/gdkx.h>
@@ -984,6 +986,8 @@ nautilus_application_present_spatial_window (NautilusApplication *application,
 									   screen);
 }
 
+#ifdef HAVE_STARTUP_NOTIFICATION
+
 static void
 sn_error_trap_push (SnDisplay *display,
                     Display   *xdisplay)
@@ -1034,8 +1038,14 @@ end_startup_notification (GtkWidget  *widget,
 					   gdk_screen_get_number (screen),
 					   startup_id);
 
-	sn_launchee_context_setup_window (context,
-					  GDK_WINDOW_XWINDOW (widget->window));
+	/* Handle the setup for the window if the startup_id is valid;
+	 * I don't think it can hurt to do this even if it was
+	 * invalid, but why do the extra work...
+	 */
+	if (strncmp (sn_launchee_context_get_startup_id (context), "_TIME", 5) != 0) {
+		sn_launchee_context_setup_window (context,
+						  GDK_WINDOW_XWINDOW (widget->window));
+	}
 
 	/* Now, set the _NET_WM_USER_TIME for the new window to the timestamp
 	 * that caused the window to be launched.
@@ -1044,14 +1054,6 @@ end_startup_notification (GtkWidget  *widget,
 		gulong startup_id_timestamp;
 		startup_id_timestamp = sn_launchee_context_get_timestamp (context);
 		gdk_x11_window_set_user_time (widget->window, startup_id_timestamp);
-	} else {
-		/* Comment this out for now, as it warns way to often.
-		 * like when launching nautilus from the terminal.
-		 
-		g_warning ("Launched by a non-compliant or obsolete startup "
-			   "notification launcher.  Focus-stealing-prevention "
-			   "may fail.\n");
-		*/
 	}
   
 	sn_launchee_context_complete (context);
@@ -1059,6 +1061,8 @@ end_startup_notification (GtkWidget  *widget,
 	sn_display_unref (sn_display);
 }
 
+#endif
+
 NautilusWindow *
 nautilus_application_present_spatial_window_with_selection (NautilusApplication *application,
 							    NautilusWindow      *requesting_window,
@@ -1084,9 +1088,11 @@ nautilus_application_present_spatial_window_with_selection (NautilusApplication
 			existing_location = existing_window->details->location;
 		}
 
-		if (eel_uris_match (existing_location, location)) {
+		if (gnome_vfs_uris_match (existing_location, location)) {
+#ifdef HAVE_STARTUP_NOTIFICATION
 			end_startup_notification (GTK_WIDGET (existing_window),
 						  startup_id);
+#endif
 
 			gtk_window_present (GTK_WINDOW (existing_window));
 			if (new_selection) {
@@ -1097,8 +1103,10 @@ nautilus_application_present_spatial_window_with_selection (NautilusApplication
 	}
 
 	window = create_window (application, NAUTILUS_TYPE_SPATIAL_WINDOW, startup_id, screen);
+#ifdef HAVE_STARTUP_NOTIFICATION
 	end_startup_notification (GTK_WIDGET (window),
 				  startup_id);
+#endif
 	if (requesting_window) {
 		/* Center the window over the requesting window by default */
 		int orig_x, orig_y, orig_width, orig_height;
@@ -1141,8 +1149,10 @@ nautilus_application_create_navigation_window (NautilusApplication *application,
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
 	
 	window = create_window (application, NAUTILUS_TYPE_NAVIGATION_WINDOW, startup_id, screen);
+#ifdef HAVE_STARTUP_NOTIFICATION
 	end_startup_notification (GTK_WIDGET (window),
 				  startup_id);
+#endif
 
 	return window;
 }
