@@ -39,7 +39,6 @@
 #include <eel/eel-accessibility.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <eel/eel-input-event-box.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
@@ -50,7 +49,7 @@
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libnautilus-private/nautilus-icon-dnd.h>
-#include <libnautilus/nautilus-clipboard.h>
+#include <libnautilus-private/nautilus-clipboard.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -152,10 +151,14 @@ drag_data_received_callback (GtkWidget *widget,
 	 */
 	name_count = g_list_length (names);
 	if (name_count > 1) {
-		prompt = g_strdup_printf (_("Do you want to view %d locations?"), 
-					          name_count);	  
-		detail = g_strdup_printf (_("This will open %d separate windows."),
-		                                    name_count);			  
+		prompt = g_strdup_printf (ngettext("Do you want to view %d location?",
+						   "Do you want to view %d locations?",
+						   name_count), 
+					  name_count);
+		detail = g_strdup_printf (ngettext("This will open %d separate window.",
+						   "This will open %d separate windows.",
+						   name_count),
+					  name_count);			  
 		/* eel_run_simple_dialog should really take in pairs
 		 * like gtk_dialog_new_with_buttons() does. */
 		new_windows_for_extras = eel_run_simple_dialog 
@@ -186,7 +189,7 @@ drag_data_received_callback (GtkWidget *widget,
 		screen = gtk_window_get_screen (GTK_WINDOW (window));
 
 		for (node = names->next; node != NULL; node = node->next) {
-			new_window = nautilus_application_create_navigation_window (application, screen);
+			new_window = nautilus_application_create_navigation_window (application, NULL, screen);
 			nautilus_window_go_to (new_window, node->data);
 		}
 	}
@@ -255,6 +258,33 @@ style_set_handler (GtkWidget *widget, GtkStyle *previous_style)
 	gtk_widget_set_size_request (widget, width, -1);
 }
 
+static gboolean
+label_button_pressed_callback (GtkWidget             *widget,
+			       GdkEventButton        *event)
+{
+	NautilusNavigationWindow *window;
+	NautilusView             *view;
+	GtkWidget                *label;
+
+	if (event->button != 3) {
+		return FALSE;
+	}
+
+	window = nautilus_location_bar_get_window (widget->parent);
+	view = NAUTILUS_WINDOW (window)->content_view;
+	label = GTK_BIN (widget)->child;
+	/* only pop-up if the URI in the entry matches the displayed location */
+	if (view == NULL ||
+	    strcmp (gtk_label_get_text (GTK_LABEL (label)), LOCATION_LABEL)) {
+		return FALSE;
+	}
+
+	nautilus_view_pop_up_location_context_menu (view, event);
+
+	return FALSE;
+}
+
+
 static int
 get_editable_number_of_chars (GtkEditable *editable)
 {
@@ -370,7 +400,9 @@ nautilus_location_bar_init (NautilusLocationBar *bar)
 
 	hbox = gtk_hbox_new (0, FALSE);
 
-	event_box = eel_input_event_box_new ();
+	event_box = gtk_event_box_new ();
+	gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box), FALSE);
+	
 	gtk_container_set_border_width (GTK_CONTAINER (event_box),
 					GNOME_PAD_SMALL);
 	label = gtk_label_new (LOCATION_LABEL);
@@ -397,11 +429,16 @@ nautilus_location_bar_init (NautilusLocationBar *bar)
 
 	gtk_container_add (GTK_CONTAINER (bar), hbox);
 
+
+	/* Label context menu */
+	g_signal_connect (event_box, "button-press-event",
+			  G_CALLBACK (label_button_pressed_callback), NULL);
+
 	/* Drag source */
 	gtk_drag_source_set (GTK_WIDGET (event_box), 
 			     GDK_BUTTON1_MASK | GDK_BUTTON3_MASK,
 			     drag_types, G_N_ELEMENTS (drag_types),
-			     GDK_ACTION_LINK);
+			     GDK_ACTION_COPY | GDK_ACTION_LINK);
 	g_signal_connect_object (event_box, "drag_data_get",
 				 G_CALLBACK (drag_data_get_callback), bar, 0);
 
@@ -431,7 +468,7 @@ nautilus_location_bar_new (NautilusNavigationWindow *window)
 	/* Clipboard */
 	nautilus_clipboard_set_up_editable
 		(GTK_EDITABLE (location_bar->details->entry),
-		 nautilus_window_get_ui_container (NAUTILUS_WINDOW (window)),
+		 nautilus_window_get_ui_manager (NAUTILUS_WINDOW (window)),
 		 TRUE);
 
 	return bar;
@@ -479,7 +516,7 @@ nautilus_location_bar_set_location (NautilusNavigationBar *navigation_bar,
  * @bar: A NautilusLocationBar.
  *
  * returns a newly allocated "string" containing the mangled
- * (by eel_make_uri_from_input) text that the user typed in...maybe a URI 
+ * (by gnome_vfs_make_uri_from_input) text that the user typed in...maybe a URI 
  * but not guaranteed.
  *
  **/
@@ -492,7 +529,7 @@ nautilus_location_bar_get_location (NautilusNavigationBar *navigation_bar)
 	bar = NAUTILUS_LOCATION_BAR (navigation_bar);
 	
 	user_location = gtk_editable_get_chars (GTK_EDITABLE (bar->details->entry), 0, -1);
-	best_uri = eel_make_uri_from_input (user_location);
+	best_uri = gnome_vfs_make_uri_from_input (user_location);
 	g_free (user_location);
 	return best_uri;
 }
@@ -510,9 +547,9 @@ nautilus_location_bar_update_label (NautilusLocationBar *bar)
 	char *current_location;
 	
 	current_text = gtk_entry_get_text (GTK_ENTRY (bar->details->entry));
-	current_location = eel_make_uri_from_input (current_text);
+	current_location = gnome_vfs_make_uri_from_input (current_text);
 	
-	if (eel_uris_match (bar->details->last_location, current_location)) {
+	if (gnome_vfs_uris_match (bar->details->last_location, current_location)) {
 		gtk_label_set_text (GTK_LABEL (bar->details->label), LOCATION_LABEL);
 	} else {		 
 		gtk_label_set_text (GTK_LABEL (bar->details->label), GO_TO_LABEL);
