@@ -48,6 +48,7 @@
 #include <eel/eel-string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtkdnd.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkmenubar.h>
 #include <gtk/gtkmenuitem.h>
@@ -63,6 +64,7 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-ui-utilities.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
@@ -79,6 +81,11 @@
 
 #define MAX_TITLE_LENGTH 180
 
+#define SPATIAL_ACTION_PLACES               "Places"
+#define SPATIAL_ACTION_GO_TO_LOCATION       "Go to Location"
+#define SPATIAL_ACTION_CLOSE_PARENT_FOLDERS "Close Parent Folders"
+#define SPATIAL_ACTION_CLOSE_ALL_FOLDERS    "Close All Folders"
+
 struct _NautilusSpatialWindowDetails {
         GtkActionGroup *spatial_action_group; /* owned by ui_manager */
 	char *last_geometry;	
@@ -91,6 +98,13 @@ struct _NautilusSpatialWindowDetails {
 	GnomeVFSURI *location;
 };
 
+static GtkTargetEntry location_button_drag_types[] = {
+	{ NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE, 0, NAUTILUS_ICON_DND_GNOME_ICON_LIST },
+	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
+	{ NAUTILUS_ICON_DND_URL_TYPE, 0, NAUTILUS_ICON_DND_URL },
+	{ NAUTILUS_ICON_DND_TEXT_TYPE, 0, NAUTILUS_ICON_DND_TEXT }
+};
+
 GNOME_CLASS_BOILERPLATE (NautilusSpatialWindow, nautilus_spatial_window,
 			 NautilusWindow, NAUTILUS_TYPE_WINDOW)
 
@@ -398,6 +412,20 @@ real_set_throbber_active (NautilusWindow *window, gboolean active)
 	}
 }
 
+static void
+real_set_allow_up (NautilusWindow *window, gboolean allow)
+{
+	NautilusSpatialWindow *spatial;
+	GtkAction *action;
+
+	spatial = NAUTILUS_SPATIAL_WINDOW (window);
+
+	action = gtk_action_group_get_action (spatial->details->spatial_action_group,
+					      SPATIAL_ACTION_CLOSE_PARENT_FOLDERS);
+	gtk_action_set_sensitive (action, allow);
+
+	NAUTILUS_WINDOW_CLASS (parent_class)->set_allow_up (window, allow);
+}
 
 static void
 location_menu_item_activated_callback (GtkWidget *menu_item,
@@ -479,6 +507,19 @@ menu_popup_pos (GtkMenu   *menu,
 	*push_in = TRUE;
 }
 
+static gboolean
+location_button_pressed_callback (GtkWidget      *widget,
+				  GdkEventButton *event,
+				  NautilusWindow *window)
+{
+	if (event->button == 3 &&
+	    window->content_view != NULL) {
+		nautilus_view_pop_up_location_context_menu (window->content_view, event);
+	}
+
+	return FALSE;
+}
+
 static void
 location_button_clicked_callback (GtkWidget *widget, NautilusSpatialWindow *window)
 {
@@ -499,7 +540,7 @@ location_button_clicked_callback (GtkWidget *widget, NautilusSpatialWindow *wind
 		name = nautilus_get_uri_shortname_for_display (uri);
 		menu_item = gtk_image_menu_item_new_with_label (name);
 		if (first_item == NULL) {
-			GtkWidget *open_icon = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON);
+			GtkWidget *open_icon = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
 
 			gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), open_icon);
 
@@ -536,6 +577,80 @@ location_button_clicked_callback (GtkWidget *widget, NautilusSpatialWindow *wind
  	gtk_object_sink (GTK_OBJECT (popup));
 }
 
+static int
+get_dnd_icon_size (NautilusSpatialWindow *window)
+{
+	NautilusWindow *parent;
+	NautilusZoomLevel zoom_level;
+
+	parent = NAUTILUS_WINDOW(window);
+
+	if (parent->content_view == NULL) {
+		return NAUTILUS_ICON_SIZE_STANDARD;
+	} else {
+		zoom_level = nautilus_view_get_zoom_level (parent->content_view);
+		return nautilus_get_icon_size_for_zoom_level (zoom_level);
+	}
+	
+}
+
+static void
+location_button_drag_begin_callback (GtkWidget             *widget,
+				     GdkDragContext        *context,
+				     NautilusSpatialWindow *window)
+{
+	GdkPixbuf *pixbuf;
+
+	pixbuf = nautilus_icon_factory_get_pixbuf_for_file (NAUTILUS_WINDOW (window)->details->viewed_file,
+							    "open", get_dnd_icon_size (window));
+
+	gtk_drag_set_icon_pixbuf (context, pixbuf, 0, 0);
+
+	g_object_unref (pixbuf);
+}
+
+/* build GNOME icon list, which only contains the window's URI.
+ * If we just used URIs, moving the folder to trash
+ * wouldn't work */
+static void
+get_data_binder (NautilusDragEachSelectedItemDataGet iteratee,
+		 gpointer                            iterator_context,
+		 gpointer                            data)
+{
+	NautilusSpatialWindow *window;
+	int icon_size;
+	char *uri;
+
+	g_assert (NAUTILUS_IS_SPATIAL_WINDOW (iterator_context));
+	window = NAUTILUS_SPATIAL_WINDOW (iterator_context);
+
+	uri = gnome_vfs_uri_to_string (window->details->location,
+				       GNOME_VFS_URI_HIDE_NONE);
+
+	icon_size = get_dnd_icon_size (window);
+
+	iteratee (uri,
+		  0,
+		  0,
+		  icon_size,
+		  icon_size,
+		  data);
+
+	g_free (uri);
+}
+
+static void
+location_button_drag_data_get_callback (GtkWidget             *widget,
+					GdkDragContext        *context,
+					GtkSelectionData      *selection_data,
+					guint                  info,
+					guint                  time,
+					NautilusSpatialWindow *window)
+{
+	nautilus_drag_drag_data_get (widget, context, selection_data,
+				     info, time, window, get_data_binder); 
+}
+
 void
 nautilus_spatial_window_set_location_button  (NautilusSpatialWindow *window,
 					      const char            *location)
@@ -577,14 +692,14 @@ action_go_to_location_callback (GtkAction *action,
 }			   
 
 static GtkActionEntry spatial_entries[] = {
-  { "Places", NULL, N_("_Places") },               /* name, stock id, label */
-  { "Go to Location", NULL, N_("Open _Location..."), /* name, stock id, label */
+  { SPATIAL_ACTION_PLACES, NULL, N_("_Places") },               /* name, stock id, label */
+  { SPATIAL_ACTION_GO_TO_LOCATION, NULL, N_("Open _Location..."), /* name, stock id, label */
     "<control>L", N_("Specify a location to open"),
     G_CALLBACK (action_go_to_location_callback) },
-  { "Close Parent Folders", NULL, N_("Close P_arent Folders"), /* name, stock id, label */
+  { SPATIAL_ACTION_CLOSE_PARENT_FOLDERS, NULL, N_("Close P_arent Folders"), /* name, stock id, label */
     "<control><shift>W", N_("Close this folder's parents"),
     G_CALLBACK (action_close_parent_folders_callback) },
-  { "Close All Folders", NULL, N_("Clos_e All Folders"), /* name, stock id, label */
+  { SPATIAL_ACTION_CLOSE_ALL_FOLDERS, NULL, N_("Clos_e All Folders"), /* name, stock id, label */
     "<control>Q", N_("Close all folder windows"),
     G_CALLBACK (action_close_all_folders_callback) },
 };
@@ -614,6 +729,10 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 	gtk_widget_show (window->details->content_box);
 
 	window->details->location_button = gtk_button_new ();
+	g_signal_connect (window->details->location_button,
+			  "button-press-event",
+			  G_CALLBACK (location_button_pressed_callback),
+			  window);
 	gtk_button_set_relief (GTK_BUTTON (window->details->location_button),
 			       GTK_RELIEF_NORMAL);
 	rc_style = gtk_widget_get_modifier_style (window->details->location_button);
@@ -623,13 +742,12 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 				 rc_style);
 
 	gtk_widget_show (window->details->location_button);
-
 	hbox = gtk_hbox_new (FALSE, 3);
 	gtk_container_add (GTK_CONTAINER (window->details->location_button), 
 			   hbox);
 	gtk_widget_show (hbox);
 
-	folder_icon = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON);
+	folder_icon = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
 	gtk_box_pack_start (GTK_BOX (hbox), folder_icon, FALSE, FALSE, 0);
 	gtk_widget_show (folder_icon);
 	
@@ -642,6 +760,18 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 	gtk_box_pack_start (GTK_BOX (hbox), arrow, FALSE, FALSE, 0);
 	gtk_widget_show (arrow);
 
+	gtk_drag_source_set (window->details->location_button,
+			     GDK_BUTTON1_MASK | GDK_BUTTON2_MASK, location_button_drag_types,
+			     G_N_ELEMENTS (location_button_drag_types),
+			     GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK | GDK_ACTION_ASK);
+	g_signal_connect (window->details->location_button,
+			  "drag_begin",
+			  G_CALLBACK (location_button_drag_begin_callback),
+			  window);
+	g_signal_connect (window->details->location_button,
+			  "drag_data_get",
+			  G_CALLBACK (location_button_drag_data_get_callback),
+			  window);
 	
 	gtk_widget_set_sensitive (window->details->location_button, FALSE);
 	g_signal_connect (window->details->location_button, 
@@ -697,7 +827,8 @@ nautilus_spatial_window_class_init (NautilusSpatialWindowClass *class)
 
 	NAUTILUS_WINDOW_CLASS(class)->set_throbber_active =
 		real_set_throbber_active;
-
+	NAUTILUS_WINDOW_CLASS(class)->set_allow_up =
+		real_set_allow_up;
 
 	binding_set = gtk_binding_set_by_class (class);
 	gtk_binding_entry_add_signal (binding_set, GDK_BackSpace, GDK_SHIFT_MASK,
