@@ -48,10 +48,10 @@
 #include <eel/eel-xml-extensions.h>
 #include <libxml/parser.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkaboutdialog.h>
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-help.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
@@ -362,7 +362,7 @@ action_about_nautilus_callback (GtkAction *action,
 				gpointer user_data)
 {
 	static GtkWidget *about = NULL;
-	const char *authors[] = {
+	const gchar *authors[] = {
 		"Alexander Larsson",
 		"Ali Abdin",
 		"Anders Carlsson",
@@ -398,50 +398,68 @@ action_about_nautilus_callback (GtkAction *action,
 		"Susan Kare",
 		NULL
 	};
-	const char *copyright;
-	const char *translator_credits;
-	const char *locale;
+	const gchar *documenters[] = {
+		"GNOME Documentation Team",
+		"Sun Microsystem",
+		NULL
+	};
+	const gchar *license[] = {
+		N_("Nautilus is free software; you can redistribute it and/or modify \n"
+		   "it under the terms of the GNU General Public License as published by \n"
+		   "the Free Software Foundation; either version 2 of the License, or \n"
+		   "(at your option) any later version."),
+		N_("Nautilus is distributed in the hope that it will be useful, \n"
+		   "but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
+		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
+		   "GNU General Public License for more details."),
+		N_("You should have received a copy of the GNU General Public License \n"
+		   "along with Nautilus; if not, write to the Free Software Foundation, Inc., \n"
+		   "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA")
+	};
+	gchar *license_trans;
+	char *logo_path;
+	GdkPixbuf *logo;
+
+	license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
+				     _(license[2]), "\n\n", NULL);
 
 	if (about == NULL) {
-		/* We could probably just put a translation in en_US
-		 * instead of doing this mess, but I got this working
-		 * and I don't feel like fiddling with it any more.
-		 */
-		locale = setlocale (LC_MESSAGES, NULL);
-		if (locale == NULL
-		    || strcmp (locale, "C") == 0
-		    || strcmp (locale, "POSIX") == 0
-		    || strcmp (locale, "en_US") == 0) {
-			/* The copyright character here is in UTF-8 */
-			copyright = "Copyright \xC2\xA9 1999-2001 Eazel, Inc.";
-		} else {
-			/* Localize to deal with issues in the copyright
-			 * symbol characters -- do not translate the company
-			 * name, please.
-			 */
-			copyright = _("Copyright (C) 1999-2001 Eazel, Inc.");
-		}
+ 
+		about = gtk_about_dialog_new ();
 
 		/* Translators should localize the following string
 		 * which will be displayed at the bottom of the about
 		 * box to give credit to the translator(s).
 		 */
-		translator_credits = (strcmp (_("Translator Credits"), "Translator Credits") == 0) ?
-			NULL : _("Translator Credits");
+
+		logo_path = nautilus_pixmap_file ("nautilus-launch-icon.png");
+		logo = NULL;
+		if (logo_path != NULL) {
+			logo = gdk_pixbuf_new_from_file (logo_path, NULL);
+		}
 		
-		about = gnome_about_new (_("Nautilus"),
-					 VERSION,
-					 copyright,
-					 _("Nautilus is a graphical shell "
+		g_object_set (about,
+			      "name", _("Nautilus"),
+			      "version", VERSION,
+			      "comments", _("Nautilus is a graphical shell "
 					   "for GNOME that makes it "
 					   "easy to manage your files "
 					   "and the rest of your system."),
-					 authors,
-					 NULL,
-					 translator_credits,
-					 NULL);
-		gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (user_data));
+			      "copyright", _("Copyright \xC2\xA9 1999-2005 "
+					     "The Nautilus authors"),
+			      "license", license_trans,
+			      "authors", authors,
+			      "documenters", documenters,
+			      "translator-credits", _("translator-credits"),
+			      "logo", logo,
+			      NULL);
 		
+		if (logo != NULL) {
+			g_object_unref (logo);
+		}
+		
+		gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (user_data));
+
 		eel_add_weak_pointer (&about);
 	}
 	
@@ -619,7 +637,7 @@ static GtkActionEntry main_entries[] = {
     N_("Show the contents in less detail"),                                      /* tooltip */ 
     G_CALLBACK (action_zoom_out_callback) },
   { "Zoom Normal", GTK_STOCK_ZOOM_100,                        /* name, stock id */
-    N_("Normal Si_ze"), NULL,           /* label, accelerator */
+    N_("Normal Si_ze"), "<control>0",           /* label, accelerator */
     N_("Show the contents at the normal size"),                                      /* tooltip */ 
     G_CALLBACK (action_zoom_normal_callback) },
   { "Connect to Server", NULL,                        /* name, stock id */
@@ -634,16 +652,16 @@ static GtkActionEntry main_entries[] = {
     N_("_Computer"), NULL,           /* label, accelerator */
     N_("Go to the computer location"),                                  /* tooltip */ 
     G_CALLBACK (action_go_to_computer_callback) },
-  { "Go to Templates", NULL,                        /* name, stock id */
+  { "Go to Templates", "stock_new-template",                        /* name, stock id */
     N_("T_emplates"), NULL,           /* label, accelerator */
     N_("Go to the templates folder"),                                  /* tooltip */ 
     G_CALLBACK (action_go_to_templates_callback) },
-  { "Go to Trash", NULL,                        /* name, stock id */
+  { "Go to Trash", "gnome-fs-trash-empty",                        /* name, stock id */
     N_("_Trash"), NULL,           /* label, accelerator */
     N_("Go to the trash folder"),                                  /* tooltip */ 
     G_CALLBACK (action_go_to_trash_callback) },
-  { "Go to Burn CD", NULL,                        /* name, stock id */
-    N_("CD _Creator"), NULL,           /* label, accelerator */
+  { "Go to Burn CD", "gnome-dev-cdrom",                        /* name, stock id */
+    N_("CD/_DVD Creator"), NULL,           /* label, accelerator */
     N_("Go to the CD/DVD Creator"),                                  /* tooltip */ 
     G_CALLBACK (action_go_to_burn_cd_callback) },
 };
