@@ -274,8 +274,9 @@ nautilus_window_go_up (NautilusWindow *window, gboolean close_behind)
 	eel_g_list_free_deep (selection);
 }
 
-void
-nautilus_window_allow_up (NautilusWindow *window, gboolean allow)
+static void
+real_set_allow_up (NautilusWindow *window,
+		   gboolean        allow)
 {
 	GtkAction *action;
 	
@@ -289,6 +290,13 @@ nautilus_window_allow_up (NautilusWindow *window, gboolean allow)
 	gtk_action_set_sensitive (action, allow);
 }
 
+void
+nautilus_window_allow_up (NautilusWindow *window, gboolean allow)
+{
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 set_allow_up, (window, allow));
+}
+
 void
 nautilus_window_allow_stop (NautilusWindow *window, gboolean allow)
 {
@@ -662,23 +670,17 @@ add_view_as_menu_item (NautilusWindow *window,
 		       int index, /* extra_viewer is always index 0 */
 		       guint merge_id)
 {
-	char *tip;
 	const NautilusViewInfo *info;
-	char *label;
 	GtkRadioAction *action;
 	char *action_name;
 	ActivateViewData *data;
 
 	info = nautilus_view_factory_lookup (identifier);
-
-	label = g_strdup_printf (_("View as %s"), _(info->label_with_mnemonic));
-	tip = g_strdup_printf (_("Display this location with \"%s\""),
-			       _(info->label));
 	
 	action_name = g_strdup_printf ("view_as_%d", index);
 	action = gtk_radio_action_new (action_name,
-				       label,
-				       tip,
+				       _(info->view_as_label_with_mnemonic),
+				       _(info->display_location_label),
 				       NULL,
 				       0);
 
@@ -690,9 +692,6 @@ add_view_as_menu_item (NautilusWindow *window,
 		   as it can get deleted/changed later */
 		window->details->view_as_radio_action = action;
 	}
-	
-	g_free (label);
-	g_free (tip);
 
 	data = g_new (ActivateViewData, 1);
 	data->window = window;
@@ -1454,6 +1453,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	class->set_title = real_set_title;
 	class->set_content_view_widget = real_set_content_view_widget;
 	class->load_view_as_menu = real_load_view_as_menu;
+	class->set_allow_up = real_set_allow_up;
 
 	g_object_class_install_property (G_OBJECT_CLASS (class),
 					 ARG_APP,
